@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "bifocal" "0.0.7"
+(define-package "bifocal" "20251231.2025"
   "Split-screen scrolling for comint-mode buffers."
   '((emacs "24.4"))
   :url "https://github.com/riscy/bifocal-mode"
